@@ -2,14 +2,14 @@ package Ukigumo::Agent;
 use strict;
 use warnings;
 use 5.008005;
-our $VERSION = '0.0.5';
+our $VERSION = '0.0.6';
 use parent qw(Amon2 Amon2::Web);
 
 sub config { +{ } }
 
 use Ukigumo::Agent::Dispatcher;
 
-__PACKAGE__->load_plugin(qw(Web::JSON));
+__PACKAGE__->load_plugins(qw(Web::JSON ShareDir));
 
 sub dispatch {
     my ($c) = @_;
@@ -28,27 +28,6 @@ sub dispatch {
     sub manager { $_manager || die "Missing manager" }
 }
 
-use File::ShareDir;
-use MRO::Compat;
-use List::Util qw(first);
-
-my %SHARE_DIR_CACHE;
-sub share_dir {
-    my $c = shift;
-
-    $SHARE_DIR_CACHE{ref $c||$c} ||= sub {
-        my $d1 = File::Spec->catfile($c->base_dir, 'share');
-        return $d1 if -d $d1;
-
-        my $dist = first { $_ ne 'Amon2' && $_ ne 'Amon2::Web' && $_->isa('Amon2') } reverse @{mro::get_linear_isa(ref $c || $c)};
-           $dist =~ s!::!-!g;
-        my $d2 = File::ShareDir::dist_dir($dist);
-        return $d2 if -d $d2;
-
-        Carp::croak "Cannot find assets path($d1, $d2).";
-    }->();
-}
-
 1;
 __END__
 
